History
-------

1.0.1 (2021-14-01)
------------------
- Added support for LUX3 FL

1.0.0 (2020-09-15)
------------------
- Added multi lux support
- Changed output from numpy array to pillow
- Require serial number with function to get information
- Add get_temperature

0.1.2 (2020-06-30)
------------------
- Rename failing to pinging in print statement

0.1.1 (2020-06-11)
------------------
- Update documentation
- Make setup.py fit for PyPI
 
0.1.0 (2020-05-20)
------------------
- Update lux server to latest version

0.0.3 (2020-03-30)
------------------
- bugfix: files were not copied into package on linux

0.0.2 (2020-03-24)
------------------
- Bugfix: stop waiting for response after sending a message

0.0.1 (2020-03-16)
------------------

- Add function: Copy the luxconnector 
- Add function: focus change option
- Add function: z-stack
- Bugfix: add lux app to manifest

0.0.0 (2020-03-13)
------------------

Copied basic package a start of luxconnector
